@@ -1,11 +1,7 @@
 use quick_protobuf::deserialize_from_slice;
 use solana_program::account_info::AccountInfo;
 use solana_program::program_error::ProgramError;
-use switchboard_protos::protos::aggregator_state::mod_AggregatorState;
-use switchboard_utils::{FastRoundResultAccountData, FastRoundResult, fast_from_bytes};
-use solana_program::pubkey::Pubkey;
-use borsh::BorshDeserialize;
-use std::convert::TryInto;
+// use switchboard_utils::{FastRoundResultAccountData, FastRoundResult, fast_parse_switchboard_result};
 
 pub use switchboard_protos::protos::aggregator_state::AggregatorState;
 pub use switchboard_protos::protos::aggregator_state::RoundResult;
@@ -44,12 +40,6 @@ pub fn get_aggregator_result(aggregator: &AggregatorState) -> Result<RoundResult
     maybe_round.ok_or(ProgramError::InvalidAccountData)
 }
 
-pub fn fast_feed_result(account_info: &AccountInfo) -> Result<FastRoundResult, ProgramError> {
-    let state_buffer = account_info.try_borrow_data()?;
-    let acc_data = fast_from_bytes(&state_buffer[1..])?;
-    Ok(acc_data.result.clone())
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
